==============
Plotting: `pl`
==============
.. currentmodule:: snapatac2

.. autosummary::
    :toctree: _autosummary

    pl.tsse
    pl.umap
    pl.motif_enrichment
    pl.regions
    pl.coverage
    pl.spectral_eigenvalues
    pl.network_edge_stat
    pl.render_plot